##############################################################################
####  GetOldZClass.py
####  Author: Michael Eichner
##############################################################################

from AccessControl import ClassSecurityInfo
from Globals import InitializeClass
from Acquisition import Implicit
from Globals import Persistent
from AccessControl.Role import RoleManager
from OFS.SimpleItem import Item
from Globals import DTMLFile

class GetOldZClass (Implicit, Persistent, RoleManager, Item):
			"""
			Get all the information from a ZClass necessary to "copy" it.
			Direct copy of a ZClass not possible right now. The information
			can be used to realize a second ZClass with the same methods,
			permissions and propertysheets like the old one.
			"""
			def __init__(self,par_self,par_oldZClassPath): 
					self.__extself = par_self
					self.REQUEST = par_self.REQUEST
					self.__oldZClassPath = par_oldZClassPath
					self.__oldZClassPath_methods = par_oldZClassPath+'/propertysheets/methods'
					self.__oldZClassPath_basic = par_oldZClassPath+'/propertysheets/basic'
					self.__oldZClassPath_views = par_oldZClassPath+'/propertysheets/views'
					self.__oldZClassPath_propertysheets = par_oldZClassPath+'/propertysheets/common'
					self.__oldZClassObj = par_self.unrestrictedTraverse(par_oldZClassPath)
					self.__oldZClassObj_methods = par_self.unrestrictedTraverse(par_oldZClassPath+'/propertysheets/methods')
					self.__oldZClassObj_basic = par_self.unrestrictedTraverse(par_oldZClassPath+'/propertysheets/basic')
					self.__oldZClassObj_views = par_self.unrestrictedTraverse(par_oldZClassPath+'/propertysheets/views')
					self.__oldZClassObj_propertysheets = par_self.unrestrictedTraverse(par_oldZClassPath+'/propertysheets/common')															
					
			def czc_get_oldZClassObj_methods(self):
					"""
					Get self.__oldZClassObj_methods
					"""
					return self.__oldZClassObj_methods
					
			def czc_get_oldZClassPath_methods(self):
					"""
					Get self.__oldZClassPath_methods
					"""
					return self.__oldZClassPath_methods
			
			def czc_getId(self):
					"""
					Get the ID
					"""
					return self.__oldZClassObj.getId()
					
			def czc_get_methods(self):
					"""
					Get list of class methods  
					"""
					return self.__oldZClassObj_methods.objectIds()
					
			def czc_get_methods_obj(self):
					"""
					Get list of class methods with object reference 
					"""
					methodobjlist = []
					for lauf in self.__oldZClassObj_methods.objectIds():
							methodobjlist.append(self.__extself.unrestrictedTraverse(self.__oldZClassPath_methods+'/'+lauf))
					return methodobjlist
			
			def czc_get_views(self):
					"""
					Get views 
					"""
					return self.__oldZClassObj_views.data()
					
			def czc_get_ps_IdsTitle(self):
					"""
					Get Ids and title of the existing propertysheets
					"""
					tmplist = []
					for lauf in self.__oldZClassObj_propertysheets.objectIds():
							tmpmap = {}
							tmpmap['id'] = lauf
							__psobj = self.__extself.unrestrictedTraverse(self.__oldZClassPath_propertysheets + '/' + lauf)
							tmpmap['title'] = __psobj.title
							tmplist.append(tmpmap)  					
					return tmplist
					
			def czc_get_ps_Ids(self):
					"""
					Get Ids of the existing propertysheets
					"""					  
					return self.__oldZClassObj_propertysheets.objectIds()
					
			def czc_get_ps_Items(self,par_Id):
					"""
					Get items of a specific property sheet (par_Id).					 
					"""
					__psobj = self.__extself.unrestrictedTraverse(self.__oldZClassPath_propertysheets + '/' + par_Id)
					laufnr=0				
					maptmp = 	__psobj.propertyMap()					
					for lauf in maptmp:
							lauf['value']=__psobj.propertyValues()[laufnr]
							laufnr = laufnr + 1
					return maptmp
			
			def czc_get_ps_Permissions(self,par_Id):
					"""
					Get permissions of a specific property sheet (par_Id).					 
					"""
					__psobj = self.__extself.unrestrictedTraverse(self.__oldZClassPath_propertysheets + '/' + par_Id)
					return __psobj.manage_getPermissionMapping()
					
			def czc_get_DefinedPermissions(self):
					"""
					Get defined class permissions
					"""					
					return self.__oldZClassObj._zclass_.__ac_permissions__
					
			def czc_get_InheritedPermissions(self):
					"""
					Get inherited class permissions
					"""
					return self.__oldZClassObj.classInheritedPermissions()
					
			def czc_get_PermissionMapping(self):
					"""
					Get permission mapping (view: Define Permissions)
					"""
					return self.__oldZClassObj.manage_getPermissionMapping()
					
			def czc_get_basic_classid(self):
					"""
					Get Class Id (view: basic)
					"""
					return self.__oldZClassObj_basic.class_id()
					
			def czc_get_basic_metatype(self):
					"""
					Get metatype (view: basic)
					"""
					return self.__oldZClassObj_basic.classMetaType()
					
			def czc_get_basic_title(self):
					"""
					Get title (view: basic)
					"""
					return self.__oldZClassObj_basic.title
					
			def czc_get_basic_iconpath(self):
					"""
					Get iconpath (view: basic)
					"""
					return self.__oldZClassObj_basic.classIcon()
					
					
			def czc_get_basic_iconimage(self):
					"""
					Get iconimage (view: basic)
					"""
					return self.__oldZClassObj.getClassAttr('ziconImage', None)
					
					
			def czc_get_basic_bases(self):
					"""
					Get bases (view: basic)
					"""
					return self.__oldZClassObj_basic.ZClassBaseClassNames()
